@@ -3,7 +3,9 @@ c	(->   ----------------------------------------------
 
 	real*8  RecoilKineMinE  !2  Recoil Kinetic Min Energy above which the recoil (=knock-on process)
                                 ! is treated. Below this energy, the effect is included as continuous
-                                ! energy loss.
+                                ! energy loss.  This is almost obsolete, but used only if KnockOnRatio>1.
+                                ! See also KnockOnRatio.
+        real*8 KnockOnRatio   !2  KnockOnRatio* KEminoObs is used as if RecoilKineMinE abvoe. (If < 1.)
 	real*8  X0            !2  radiation length in kg/m2 for air
 	real*8  Ecrit         !2  critical energy in GeV. 
                               !  employed only when calculating air shower size in the hybrid 
@@ -19,7 +21,8 @@ c	(->   ----------------------------------------------
                               !
                               !  at around shower maximum.   Hybrid AS is always essentially 1-D.
 
-	logical Knockon       !2  if T, Knockon process is considered
+	logical Knockon       !2  Obsolete. If T, Knockon process is considered. Giving F is possible by
+                              !   giving large RecoilKineMinE.
 	real*8  AnihiE        !2  if E(positron)  < Eanihi, annihilation is  considered. 
 	real*8  Es            !2  Modified scattering constant. 19.3d-3 GeV
 	real*8  MaxComptonE   !2 Above this energy, Compton is neglected. 
@@ -37,7 +40,9 @@ c	(->   ----------------------------------------------
 
 c	<-)	----------------------------------------------
 
-	common /Zelemagc/  RecoilKineMinE, AnihiE, MaxComptonE,
+	common /Zelemagc/  RecoilKineMinE, KnockOnRatio,
+     *  AnihiE, MaxComptonE,
      *  MaxPhotoE, MinPhotoProdE,   Es, X0, Ecrit, Knockon, 
      *  PhotoProd, Moliere
 
+
