@@ -11,9 +11,10 @@ c              eventLoop
 
       record /track/ incident
       integer jold
+      integer fin  
 
-      do while (EventNo .lt.  DestEventNo(1) .and. 
-     *      EventsInTheRun .lt. DestEventNo(2))
+      do while (EventNo .lt. abs( DestEventNo(1)) .and. 
+     *      EventsInTheRun .lt. abs( DestEventNo(2)))
          EventsInTheRun = EventsInTheRun + 1
          EventNo = EventNo + 1
 c             switch to the random number generator 1
@@ -26,18 +27,12 @@ c                reset the seed.
          else
 c              save the initial seed of random number
             call rnd1s(SeedSave)
-c            if(Job .eq. 'skeleton') then
-c               call cwriteSeed
-c            elseif(Job .ne. 'flesh' .and. SeedFile .ne. ' ') then
-c               call cwriteSeed
-c            endif
-c             take record  of seed, if non flesh, non skeleton
-c             job and SeedFile is given.
             if(Job .eq. ' ' .and. SeedFile .ne. ' ') then
                call cwriteSeed
             endif
          endif            
-         call cmkIncident(incident)
+         call cmkIncident(incident, fin)
+         if(fin .ne. 0) goto 10  ! all including cuoffed end
          call ciniTracking    ! init for tracking each event
          call cinitStack
          call cpush(incident)
@@ -49,6 +44,7 @@ c             job and SeedFile is given.
          call chookEnEvent    ! user hook for each event  end
 
       enddo
+ 10   continue
       end
 c     ****************************************************
 c          inquire the initial random seed
