@@ -260,21 +260,17 @@ c            endif
       endif
       if(.not. cross .or. ObsPlane .eq. notUsed) then
 c
-         if(ObsPlane .ne. spherical) then 
-            call cscalerProd(MovedTrack.vec.w, DcAtObsXyz, cosfromaxis)
-            if(cosfromaxis .lt. BackAngLimit ) then
-c             discard it
-               MoveStat = BorderH
-               return              !  ***************
-            endif
-         endif
 c            see if go out of outer boundery.
-c  -------------------------------------------------------------
-         if(MovedTrack.pos.height .ge. BorderHeightH) then
-c            discard it
+         call cscalerProd(MovedTrack.vec.w, DcAtObsXyz, cosfromaxis)
+         if(cosfromaxis .lt. BackAngLimit .or.
+     *        MovedTrack.pos.height .ge. BorderHeightH) then
+c             discard it
             MoveStat = BorderH
             return              !  ***************
          endif
+c  -------------------------------------------------------------
+
+
          if(MovedTrack.pos.height .le. BorderHeightL) then
             MoveStat = BorderL
 c         leng = clenbetween2h(TrackBefMove.pos.height+Eradius,
