@@ -20,7 +20,7 @@ c     *****************************************************************
 #include  "Zcmuint.h"
 c     **************************************************
 c
-      real*8 mfp, ek,  xs, et, mass, ctau, prob, path
+      real*8 mfp, ek,  xs, et, mass, prob, path
 c            
 c        m.f.p (kg/m**2) = abn /xsec(mb)
 c        parameter (aira=14.5, abogn=6.02e23, abn=aira*1.e28/abogn)
@@ -30,7 +30,7 @@ c        parameter (aira=14.5, abogn=6.02e23, abn=aira*1.e28/abogn)
       real*8  eps/1.e-8/, smallxs/1.e-10/, largexs/1.e10/
       integer ica, ka
       logical useInt2
-      record /fmom/ gb
+
       character*70 msg
 
       et = TrackBefMove.p.fm.p(4)
@@ -38,19 +38,8 @@ c        parameter (aira=14.5, abogn=6.02e23, abn=aira*1.e28/abogn)
       ek = max(et - mass, eps)    ! avoid 0 energy.
       ka = TrackBefMove.p.code
       ica = TrackBefMove.p.charge
-      call cgetctau(TrackBefMove.p, ctau)
-      if(ctau .ne. Infty) then
-         if(ek .ne. eps) then
-c            get gamma x beta in vector
-            call cgetlf(TrackBefMove.p, gb)
-c             sample decay length
-            call rndc(u)
-            length =
-     *        - ctau * sqrt(gb.p(1)**2 + gb.p(2)**2 + gb.p(3)**2)
-     *           * log(u)
-         else
-            length = 0.
-         endif
+      call cdecayLeng(TrackBefMove, length)
+      if(length .ne. Infty) then
          call csetIntInf(length, .true., 'decay')
       endif
 
